@@ -381,8 +381,10 @@ CREATE TABLE IF NOT EXISTS datasets (
         try:
             cursor = connection.cursor()
             try:
-                for _ in cursor.execute(schema_sql, multi=True):
-                    pass
+                # Execute each SQL statement separately to avoid multi-statement driver bugs.
+                for statement in schema_sql.split(";"):
+                    if statement.strip():
+                        cursor.execute(statement)
             finally:
                 cursor.close()
             connection.commit()
